This tribunal is responsible for handling appeals against decisions made by the Employment Tribunal where a legal mistake may have been made in the case. They also hear appeals and applications about decisions made by the certification officer and the Central Arbitration Committee.

This tribunal began to regularly transfer decisions to The National Archives in 2022. The oldest decision from this tribunal included in Find Case Law is from {start_year}.

You can read more about it on the [Employment Appeal tribunal page](https://www.gov.uk/courts-tribunals/employment-appeal-tribunal){target="\_blank"} on the [HM Courts and Tribunals Service website](https://www.gov.uk/government/organisations/hm-courts-and-tribunals-service/about){target="\_blank"}.
